@@ -2,22 +2,20 @@ import argparse
 import logging
 
 import google.cloud.exceptions
-import pandas as pd
-from botocore.session import get_session
-from numcodecs import blosc
-
-from aind_data_transfer.gcs import create_client
-from aind_data_transfer.transcode.ome_zarr import write_files
-from aind_data_transfer.util.file_utils import *
-from aind_data_transfer.util.dask_utils import get_client
-from aind_data_transfer.util.env_utils import find_hdf5plugin_path
 
 # Importing this alone doesn't work on HPC
 # Must manually override HDF5_PLUGIN_PATH environment variable
 # in each Dask worker
 import hdf5plugin
+import pandas as pd
+from botocore.session import get_session
+from numcodecs import blosc
 
-
+from aind_data_transfer.gcs import create_client
+from aind_data_transfer.transformations.ome_zarr import write_files
+from aind_data_transfer.util.dask_utils import get_client
+from aind_data_transfer.util.env_utils import find_hdf5plugin_path
+from aind_data_transfer.util.file_utils import *
 
 blosc.use_threads = False
 
@@ -160,6 +158,12 @@ def parse_args():
         default=None,
         help='Voxel size of the dataset as a string of floats in XYZ order, e.g. "0.3,0.3,1.0"',
     )
+    parser.add_argument(
+        "--bkg_img_dir",
+        type=str,
+        default=None,
+        help="path to the background image folder. If given, background subtraction will be done for each converted image."
+    )
     args = parser.parse_args()
     return args
 
@@ -192,7 +196,7 @@ def main():
             "HDF5_PLUGIN_PATH": find_hdf5plugin_path(),
             "HDF5_USE_FILE_LOCKING": "FALSE",
             "OMP_NUM_THREADS": "1",
-            "MALLOC_TRIM_THRESHOLD_": "0"
+            "MALLOC_TRIM_THRESHOLD_": "0",
         }
     }
     client, _ = get_client(args.deployment, worker_options=worker_options)
@@ -235,11 +239,15 @@ def main():
         args.chunk_shape,
         voxsize,
         opts,
+        bkg_img_dir=args.bkg_img_dir
     )
 
     df = pd.DataFrame.from_records(all_metrics)
     df.to_csv(args.metrics_file, index_label="test_number")
 
+    client.shutdown()
+    client.close()
+
 
 if __name__ == "__main__":
     main()
