@@ -3,20 +3,28 @@ data transfer jobs."""
 
 import argparse
 import json
-import logging
+import os
 import re
 from datetime import date, datetime, time
 from pathlib import Path
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional
 
-import boto3
+from aind_data_access_api.secrets import get_parameter
 from aind_data_schema.data_description import (
     ExperimentType,
     Modality,
     build_data_name,
 )
-from botocore.exceptions import ClientError
-from pydantic import BaseSettings, DirectoryPath, Field, FilePath, SecretStr
+from aind_data_schema.processing import ProcessName
+from pydantic import (
+    BaseSettings,
+    DirectoryPath,
+    Field,
+    FilePath,
+    PrivateAttr,
+    SecretStr,
+    validator,
+)
 
 
 class BasicJobEndpoints(BaseSettings):
@@ -31,6 +39,13 @@ class BasicJobEndpoints(BaseSettings):
     aind_data_transfer_repo_location: str = Field(...)
     video_encryption_password: Optional[SecretStr] = Field(None)
     codeocean_api_token: Optional[SecretStr] = Field(None)
+    codeocean_process_capsule_id: Optional[str] = Field(
+        None,
+        description=(
+            "If defined, will run this Code Ocean Capsule after registering "
+            "the data asset"
+        ),
+    )
 
     class Config:
         """This class will add custom sourcing from aws."""
@@ -47,39 +62,19 @@ class BasicJobEndpoints(BaseSettings):
             A function that retrieves the credentials.
             """
 
-            def get_param_from_aws(
-                aws_param_store_name, aws_ssm_client, with_decryption=False
-            ) -> Dict[str, Any]:
-                """Pull parameter from AWS Parameter Store"""
-                try:
-                    param_from_store = aws_ssm_client.get_parameter(
-                        Name=aws_param_store_name,
-                        WithDecryption=with_decryption,
-                    )
-                    param_string = param_from_store["Parameter"]["Value"]
-                    params = json.loads(param_string)
-                except ClientError as e:
-                    logging.warning(
-                        f"Unable to retrieve parameters from aws: {e.response}"
-                    )
-                    params = {}
-                return params
-
             def set_settings(_: BaseSettings) -> Dict[str, Any]:
                 """
                 A simple settings source that loads from aws secrets manager
                 """
-                ssm_client = boto3.client("ssm")
-                params_from_aws = get_param_from_aws(
-                    aws_param_store_name=param_name, aws_ssm_client=ssm_client
-                )
+                params_from_aws = json.loads(get_parameter(param_name))
                 if params_from_aws.get("video_encryption_password_path"):
-                    video_encrypt_pwd = get_param_from_aws(
-                        aws_ssm_client=ssm_client,
-                        aws_param_store_name=params_from_aws.get(
-                            "video_encryption_password_path"
-                        ),
-                        with_decryption=True,
+                    video_encrypt_pwd = json.loads(
+                        get_parameter(
+                            params_from_aws.get(
+                                "video_encryption_password_path"
+                            ),
+                            with_decryption=True,
+                        )
                     )
                     params_from_aws[
                         "video_encryption_password"
@@ -87,20 +82,17 @@ class BasicJobEndpoints(BaseSettings):
                     if params_from_aws.get("video_encryption_password_path"):
                         del params_from_aws["video_encryption_password_path"]
                 if params_from_aws.get("codeocean_api_token_path"):
-                    co_api_token = get_param_from_aws(
-                        aws_ssm_client=ssm_client,
-                        aws_param_store_name=params_from_aws.get(
-                            "codeocean_api_token_path"
-                        ),
-                        with_decryption=True,
+                    co_api_token = json.loads(
+                        get_parameter(
+                            params_from_aws.get("codeocean_api_token_path"),
+                            with_decryption=True,
+                        )
                     )
                     params_from_aws["codeocean_api_token"] = co_api_token.get(
                         "CODEOCEAN_READWRITE_TOKEN"
                     )
                     if params_from_aws.get("codeocean_api_token_path"):
                         del params_from_aws["codeocean_api_token_path"]
-
-                ssm_client.close()
                 return params_from_aws
 
             return set_settings
@@ -131,6 +123,58 @@ class BasicJobEndpoints(BaseSettings):
                 )
 
 
+class ModalityConfigs(BaseSettings):
+    """Class to contain configs for each modality type"""
+
+    # Optional number id to assign to modality config
+    _number_id: Optional[int] = PrivateAttr(default=None)
+    modality: Modality = Field(
+        ..., description="Data collection modality", title="Modality"
+    )
+    source: DirectoryPath = Field(
+        ...,
+        description="Location of raw data to be uploaded",
+        title="Data Source",
+    )
+    compress_raw_data: Optional[bool] = Field(
+        default=None,
+        description="Run compression on data",
+        title="Compress Raw Data",
+    )
+    extra_configs: Optional[FilePath] = Field(
+        default=None,
+        description="Location of additional configuration file",
+        title="Extra Configs",
+    )
+
+    @property
+    def number_id(self):
+        """Retrieve an optionally assigned numerical id"""
+        return self._number_id
+
+    @property
+    def default_output_folder_name(self):
+        """Construct the default folder name for the modality."""
+        if self._number_id is None:
+            return self.modality.name.lower()
+        else:
+            return self.modality.name.lower() + str(self._number_id)
+
+    @validator("compress_raw_data", always=True)
+    def get_compress_source_default(
+        cls, compress_source: Optional[bool], values: Dict[str, Any]
+    ) -> bool:
+        """Set compress source default to True for ecephys data."""
+        if (
+            compress_source is None
+            and "modality" in values
+            and values["modality"] == Modality.ECEPHYS
+        ):
+            return True
+        else:
+            return False
+
+
 class BasicUploadJobConfigs(BasicJobEndpoints):
     """Configuration for the basic upload job"""
 
@@ -142,8 +186,10 @@ class BasicUploadJobConfigs(BasicJobEndpoints):
     experiment_type: ExperimentType = Field(
         ..., description="Experiment type", title="Experiment Type"
     )
-    modality: Modality = Field(
-        ..., description="Data collection modality", title="Modality"
+    modalities: List[ModalityConfigs] = Field(
+        ...,
+        description="Data collection modalities and their directory location",
+        title="Modalities",
     )
     subject_id: str = Field(..., description="Subject ID", title="Subject ID")
     acq_date: date = Field(
@@ -154,10 +200,10 @@ class BasicUploadJobConfigs(BasicJobEndpoints):
         description="Time of day data was acquired",
         title="Acquisition Time",
     )
-    data_source: DirectoryPath = Field(
-        ...,
-        description="Location of raw data to be uploaded",
-        title="Data Source",
+    process_name: ProcessName = Field(
+        default=ProcessName.OTHER,
+        description="Type of processing performed on the raw data source.",
+        title="Process Name",
     )
     temp_directory: Optional[DirectoryPath] = Field(
         default=None,
@@ -178,11 +224,6 @@ class BasicUploadJobConfigs(BasicJobEndpoints):
         description="Directory of metadata",
         title="Metadata Directory",
     )
-    extra_configs: Optional[FilePath] = Field(
-        default=None,
-        description="Location of additional configuration file",
-        title="Extra Configs",
-    )
     log_level: str = Field(
         default="WARNING",
         description="Logging level. Default is WARNING.",
@@ -201,10 +242,12 @@ class BasicUploadJobConfigs(BasicJobEndpoints):
         description="Perform a dry-run of data upload",
         title="Dry Run",
     )
-    compress_raw_data: bool = Field(
+    force_cloud_sync: bool = Field(
         default=False,
-        description="Run compression on data",
-        title="Compress Raw Data",
+        description=(
+            "Force syncing of data folder even if location exists in cloud"
+        ),
+        title="Force Cloud Sync",
     )
 
     @property
@@ -270,13 +313,6 @@ class BasicUploadJobConfigs(BasicJobEndpoints):
             type=str,
             help=_help_message("s3_bucket"),
         )
-        parser.add_argument(
-            "-d",
-            "--data-source",
-            required=True,
-            type=str,
-            help=_help_message("data_source"),
-        )
         parser.add_argument(
             "-e",
             "--experiment-type",
@@ -286,10 +322,13 @@ class BasicUploadJobConfigs(BasicJobEndpoints):
         )
         parser.add_argument(
             "-m",
-            "--modality",
+            "--modalities",
             required=True,
             type=str,
-            help=_help_message("modality"),
+            help=(
+                f"String that can be parsed as json list where each entry "
+                f"has fields: {ModalityConfigs.__fields__}"
+            ),
         )
         parser.add_argument(
             "-p",
@@ -316,13 +355,6 @@ class BasicUploadJobConfigs(BasicJobEndpoints):
             help="Time data was acquired, HH-mm-ss or HH:mm:ss",
         )
         # Optional
-        parser.add_argument(
-            "-c",
-            "--extra-configs",
-            required=False,
-            type=str,
-            help=_help_message("extra_configs"),
-        )
         parser.add_argument(
             "-l",
             "--log-level",
@@ -354,41 +386,43 @@ class BasicUploadJobConfigs(BasicJobEndpoints):
         parser.add_argument(
             "--dry-run", action="store_true", help=_help_message("dry_run")
         )
-        parser.add_argument(
-            "--compress-raw-data",
-            action="store_true",
-            help=_help_message("compress_raw_data"),
-        )
         parser.add_argument(
             "--metadata-dir-force",
             action="store_true",
             help=_help_message("metadata_dir_force"),
         )
+        parser.add_argument(
+            "--force-cloud-sync",
+            action="store_true",
+            help=_help_message("force_cloud_sync"),
+        )
+        parser.add_argument(
+            "-i",
+            "--codeocean-process-capsule-id",
+            required=False,
+            type=str,
+            help=_help_message("codeocean_process_capsule_id"),
+        )
         parser.set_defaults(dry_run=False)
-        parser.set_defaults(compress_raw_data=False)
         parser.set_defaults(metadata_dir_force=False)
+        parser.set_defaults(force_cloud_sync=False)
         job_args = parser.parse_args(args)
         acq_date = BasicUploadJobConfigs.parse_date(job_args.acq_date)
         acq_time = BasicUploadJobConfigs.parse_time(job_args.acq_time)
         behavior_dir = (
             None
             if job_args.behavior_dir is None
-            else Path(job_args.behavior_dir)
+            else Path(os.path.abspath(job_args.behavior_dir))
         )
         metadata_dir = (
             None
             if job_args.metadata_dir is None
-            else Path(job_args.metadata_dir)
+            else Path(os.path.abspath(job_args.metadata_dir))
         )
         temp_directory = (
             None
             if job_args.temp_directory is None
-            else Path(job_args.temp_directory)
-        )
-        extra_configs = (
-            None
-            if job_args.extra_configs is None
-            else Path(job_args.extra_configs)
+            else Path(os.path.abspath(job_args.temp_directory))
         )
         log_level = (
             BasicUploadJobConfigs.__fields__["log_level"].default
@@ -408,21 +442,25 @@ class BasicUploadJobConfigs(BasicJobEndpoints):
             endpoints_param_dict = {
                 "aws_param_store_name": job_args.endpoints_parameters
             }
+        if job_args.codeocean_process_capsule_id is not None:
+            endpoints_param_dict[
+                "codeocean_process_capsule_id"
+            ] = job_args.codeocean_process_capsule_id
+        modalities_json = json.loads(job_args.modalities)
+        modalities = [ModalityConfigs.parse_obj(m) for m in modalities_json]
         return cls(
             s3_bucket=job_args.s3_bucket,
-            data_source=Path(job_args.data_source),
             subject_id=job_args.subject_id,
-            modality=Modality(job_args.modality),
             experiment_type=ExperimentType(job_args.experiment_type),
+            modalities=modalities,
             acq_date=acq_date,
             acq_time=acq_time,
             behavior_dir=behavior_dir,
             temp_directory=temp_directory,
             metadata_dir=metadata_dir,
-            extra_configs=extra_configs,
             dry_run=job_args.dry_run,
-            compress_raw_data=job_args.compress_raw_data,
             metadata_dir_force=job_args.metadata_dir_force,
+            force_cloud_sync=job_args.force_cloud_sync,
             log_level=log_level,
             **endpoints_param_dict,
         )
