@@ -23,6 +23,7 @@ from requests import Response
 from requests.exceptions import ConnectionError, JSONDecodeError
 
 from aind_data_transfer import __version__ as aind_data_transfer_version
+from aind_data_transfer.config_loader.base_config import ModalityConfigs
 
 
 class MetadataCreation(ABC):
@@ -313,7 +314,60 @@ class ProcessingMetadata(MetadataCreation):
         processing_instance = Processing(
             data_processes=[data_processing_instance]
         )
-        return cls(model_obj=processing_instance.dict())
+        # Do this to use enum strings instead of classes in dict representation
+        contents = json.loads(processing_instance.json())
+        return cls(model_obj=contents)
+
+    @classmethod
+    def from_modalities_configs(
+        cls,
+        modality_configs: List[ModalityConfigs],
+        start_date_time: datetime,
+        end_date_time: datetime,
+        output_location: str,
+        code_url: str,
+        notes: Optional[str] = None,
+    ):
+        """
+        Build a ProcessingMetadata instance using some basic parameters.
+        Parameters
+        ----------
+        modality_configs : List[ModalityConfigs]
+          List of modality configs
+        start_date_time : datetime
+          Start date and time of the process
+        end_date_time : datetime
+          End date and time of the process
+        output_location : str
+          Location of the files that are being processed
+        code_url : str
+          Location of the processing code
+        notes : Optional[str]
+          Optional notes. Defaults to None.
+
+        """
+        data_processes = []
+        for modality_config in modality_configs:
+            if modality_config.modality == Modality.ECEPHYS:
+                process_name = ProcessName.EPHYS_PREPROCESSING
+            else:
+                process_name = ProcessName.OTHER
+            data_processing_instance = DataProcess(
+                name=process_name.value,
+                version=aind_data_transfer_version,
+                start_date_time=start_date_time,
+                end_date_time=end_date_time,
+                input_location=str(modality_config.source),
+                output_location=output_location,
+                code_url=code_url,
+                parameters=modality_config.dict(),
+                notes=notes,
+            )
+            data_processes.append(data_processing_instance)
+        processing_instance = Processing(data_processes=data_processes)
+        # Do this to use enum strings instead of classes in dict representation
+        contents = json.loads(processing_instance.json())
+        return cls(model_obj=contents)
 
 
 class RawDataDescriptionMetadata(MetadataCreation):
@@ -334,6 +388,7 @@ class RawDataDescriptionMetadata(MetadataCreation):
         funding_source: Optional[Tuple] = (
             Funding(funder=Institution.AIND.value.abbreviation),
         ),
+        investigators: Optional[List[str]] = None,
     ):
         """
         Build a RawDataDescriptionMetadata instance using some basic
@@ -348,6 +403,7 @@ class RawDataDescriptionMetadata(MetadataCreation):
           Primary Institution. Defaults to AIND.
         funding_source : Optional[Tuple]
           Tuple of funding sources. Defaults to (AIND)
+        investigators : Optional[List[str]]
 
         """
         funding_source_list = (
@@ -355,11 +411,15 @@ class RawDataDescriptionMetadata(MetadataCreation):
             if isinstance(funding_source, tuple)
             else funding_source
         )
+        investigators = [] if investigators is None else investigators
         basic_settings = RawDataDescription.parse_name(name=name)
         data_description_instance = RawDataDescription(
             institution=institution,
             modality=modality,
             funding_source=funding_source_list,
+            investigators=investigators,
             **basic_settings,
         )
-        return cls(model_obj=data_description_instance.dict())
+        # Do this to use enum strings instead of classes in dict representation
+        contents = json.loads(data_description_instance.json())
+        return cls(model_obj=contents)
