@@ -1,12 +1,21 @@
+"""
+Imaging writers for the different data modalities
+"""
 import logging
 import os
 import re
 from datetime import date, datetime, time
 from pathlib import Path
-from typing import List, Tuple, Union
+from typing import Any, List, Tuple, Union
 
+import chardet
 from aind_data_schema import Funding, RawDataDescription, Subject
-from aind_data_schema.data_description import ExperimentType, Modality, Institution, Group
+from aind_data_schema.data_description import (
+    ExperimentType,
+    Group,
+    Institution,
+    Modality,
+)
 from aind_data_schema.imaging import acquisition, tile
 from aind_metadata_service.client import AindMetadataServiceClient
 
@@ -55,7 +64,11 @@ def digest_asi_line(line: str) -> datetime:
     hms = [int(i) for i in hms.split(b":")]
     if ampm == b"PM":
         hms[0] += 12
+        if hms[0] == 24:
+            hms[0] = 0
+
     ymdhms = ymd + hms
+
     dtime = datetime(*ymdhms)
     ymd = date(*ymd)
     hms = time(*hms)
@@ -89,39 +102,200 @@ def get_session_end(asi_file) -> datetime:
     return result
 
 
-def get_scale(lc_mdata) -> tile.Scale3dTransform:
+def get_line_indices_metadata_file(lines: bytes) -> dict:
     """
-    Get scales metadata
+    Get the index location in the text file
+    where each block of metadata information
+    starts
 
     Parameters
     -----------
-    lc_mdata: List[bytes]
-        List with bytes containing the
-        scale information
+    lines: bytes
+        Bytes with the metadata information
+        taken from the text file
 
     Returns
     -----------
-    aind_data_schema.imaging.tile.Scale3dTransform
-        Scales for the imaging data
+    dict
+        Dictionary with the indices of
+        each block of metadata
+    """
+    indices = {
+        "info_start": None,
+        "wavelength_start": None,
+        "tile_acquisition_start": None,
+    }
+
+    total_lines = len(lines)
+
+    for idx_line in range(total_lines):
+        splited_line = lines[idx_line].rstrip().split("\t")
+
+        if "Obj" in splited_line:
+            indices["info_start"] = idx_line
+
+        if "Wavelength" in splited_line:
+            indices["wavelength_start"] = idx_line
+
+        if "Exposure" in splited_line:
+            indices["tile_acquisition_start"] = idx_line
+            break
+
+    return indices
+
+
+def get_session_config(lines: List[str]) -> dict:
+    """
+    Gets the session config
+
+    Parameters
+    -----------
+    lines: List[str]
+        List with the lines of the
+        metadata file
+
+    Returns
+    -----------
+    Dictionary with the parsed data
+    """
+    # Get objective magnification
+    objective_regex = r"\d+\.?\d*"  # "(\d+\.?\d*)(x|X)" to get with X
+
+    data = {}
+    lines_splited = lines[1].rstrip().split("\t")
+
+    # Getting first line metadata
+    obj = lines_splited[0]
+    v_res = float(lines_splited[1])
+    um_per_pix = float(lines_splited[2])
+    z_step = float(lines_splited[3])
+    scanning = lines_splited[4]
+    sampling = lines_splited[5]
+    destripe = lines_splited[6]
+    z_block = int(lines_splited[7])
+
+    data["obj_name"] = obj
+    data["obj_magnification"] = re.findall(objective_regex, obj)[0]
+    data["v_res"] = v_res
+    data["um/pix"] = um_per_pix
+    data["z_step_um"] = z_step
+    data["scanning"] = scanning
+    data["sampling"] = sampling
+    data["destripe"] = destripe
+    data["z_block"] = z_block
+
+    return data
+
+
+def get_wavelength_config(lines: List[str], start_index: int, end_index: int):
+    """
+    Gets the wavelength config
+
+    Parameters
+    -----------
+    lines: List[str]
+        List with the lines of the
+        metadata file
+
+    start_index: int
+        Index with the line where
+        we'll parse the data
+
+    end_index: int
+        Index with the line where
+        we'll finish
+
+    Returns
+    -----------
+    Dictionary with the parsed data
+    """
+    wavelengths = {}
+    for line in lines[start_index:end_index]:
+        line_splited = line.rstrip().split("\t")
+
+        try:
+            wavelength = int(line_splited[0])
+            power_l = float(line_splited[1])
+            power_r = float(line_splited[2])
+
+            wavelengths[wavelength] = {}
+            wavelengths[wavelength]["power_left"] = power_l
+            wavelengths[wavelength]["power_right"] = power_r
+
+        except ValueError as err:
+            logger.error(
+                f"An error ocurred while parsing {line_splited} Traceback: {err}"
+            )
+    return wavelengths
+
+
+def get_tile_info(lines: List[str], start_index: int):
+    """
+    Gets the tile config
+
+    Parameters
+    -----------
+    lines: List[str]
+        List with the lines of the
+        metadata file
+
+    start_index: int
+        Index with the line where
+        we'll parse the data
+
+    Returns
+    -----------
+    Dictionary with the parsed data
     """
 
-    line = lc_mdata[1]
-    xy, z = line.split()[3:5]
-    scale = tile.Scale3dTransform(scale=[xy, xy, z])
+    data = {}
+    ite = 0
 
-    return scale
+    for line in lines[start_index:]:
+        splited_line = line.rstrip().split("\t")
+        line_elements = len(splited_line)
+
+        if not line_elements or (line_elements == 1 and splited_line[0] == ""):
+            # End of file when reading from bucket
+            break
+
+        name = f"t_{ite}"
+
+        x = int(splited_line[0])
+        y = int(splited_line[1])
+        z = int(splited_line[2])
+        wavelength = int(splited_line[3])
+        side = int(splited_line[4])
+        exposure = int(splited_line[5])
+        skip = int(splited_line[6])
+
+        data[name] = {
+            "x": x,
+            "y": y,
+            "z": z,
+            "wavelength": wavelength,
+            "side": side,
+            "exposure": exposure,
+            "skip": skip,
+        }
+        ite += 1
+
+    return data
 
 
-def make_acq_tiles(lc_mdata: bytes, filter_mapping: dict):
+def make_acq_tiles(metadata_dict: dict, filter_mapping: dict):
     """
     Makes metadata for the acquired tiles of
     the dataset
 
     Parameters
     -----------
-    lc_mdata: List[bytes]
-        List with bytes containing the
-        scale information
+    metadata_dict: dict
+        Dictionary with the acquisition metadata
+        coming from the microscope
+
+    filter_mapping: dict
+        Dictionary with the channel names
 
     Returns
     -----------
@@ -131,52 +305,54 @@ def make_acq_tiles(lc_mdata: bytes, filter_mapping: dict):
 
     channels = {}
 
-    wavelength_line = None
-    tiles_line = None
+    # List where the metadata of the acquired
+    # tiles is stored
+    tile_acquisitions = []
 
-    for idx_line in range(len(lc_mdata)):
+    filter_wheel_idx = 0
+    for wavelength, value in metadata_dict["wavelength_config"].items():
+        channel = tile.Channel(
+            channel_name=wavelength,
+            laser_wavelength=wavelength,
+            laser_power=value["power_left"],
+            filter_wheel_index=filter_wheel_idx,
+        )
+        filter_wheel_idx += 1
 
-        if "Wavelength" in str(lc_mdata[idx_line]):
-            wavelength_line = idx_line + 1
+        channels[wavelength] = channel
 
-        elif "Skip" in str(lc_mdata[idx_line]):
-            tiles_line = idx_line + 1
+    # Scale metadata
+    scale = tile.Scale3dTransform(
+        scale=[
+            metadata_dict["session_config"]["um/pix"],  # X res
+            metadata_dict["session_config"]["um/pix"],  # Y res
+            metadata_dict["session_config"]["z_step_um"],  # Z res
+        ]
+    )
 
-    tiles = []
+    for tile_key, tile_info in metadata_dict["tile_config"].items():
+        tile_transform = tile.Translation3dTransform(
+            translation=[
+                tile_info["x"] / 10,
+                tile_info["y"] / 10,
+                tile_info["z"] / 10,
+            ]
+        )
 
-    if wavelength_line and tiles_line:
-        for idx, l in enumerate(lc_mdata[wavelength_line : tiles_line - 1]):
-            wavelength, powerl, powerr = [float(j) for j in l.split()]
+        channel = channels[tile_info["wavelength"]]
 
-            channel = tile.Channel(
-                channel_name=wavelength,
-                laser_wavelength=wavelength,
-                laser_power=powerl,
-                filter_wheel_index=idx,
-            )
+        tile_acquisition = tile.AcquisitionTile(
+            channel=channel,
+            notes=(
+                "\nLaser power is in percentage of total, it needs calibration"
+            ),
+            coordinate_transformations=[tile_transform, scale],
+            file_name=f"Ex_{tile_info['wavelength']}_Em_{filter_mapping[tile_info['wavelength']]}/{tile_info['x']}/{tile_info['x']}_{tile_info['y']}/",
+        )
 
-            channels[wavelength] = channel
+        tile_acquisitions.append(tile_acquisition)
 
-        scale = get_scale(lc_mdata)
-
-        for line in lc_mdata[tiles_line:]:
-            X, Y, Z, W, S, E, Sk = [int(float(i)) for i in line.split()]
-
-            tform = tile.Translation3dTransform(
-                translation=[int(float(i)) / 10 for i in line.split()[0:3]]
-            )
-
-            channel = channels[float(W)]
-            t = tile.AcquisitionTile(
-                channel=channel,
-                notes=(
-                    "\nLaser power is in percentage of total -- needs calibration"
-                ),
-                coordinate_transformations=[tform, scale],
-                file_name=f"Ex_{W}_Em_{filter_mapping[W]}/{X}/{X}_{Y}/",
-            )
-            tiles.append(t)
-    return tiles
+    return tile_acquisitions
 
 
 class SmartSPIMWriter:
@@ -300,10 +476,33 @@ class SmartSPIMWriter:
 
         mouse_date = parsed_data["mouse_date"]
 
+        # Validating data_description args
+        institution = None
+
+        # Getting the institution
+        if "institution" not in dataset_info:
+            raise ValueError("Please, provide the institution in the manifest")
+        else:
+            institution = dataset_info["institution"]
+
+        funding_source = file_utils.helper_validate_key_dict(
+            dictionary=dataset_info,
+            key="funding_source",
+            default_return=institution,
+        )
+        project_name = file_utils.helper_validate_key_dict(
+            dictionary=dataset_info, key="project"
+        )
+        project_id = file_utils.helper_validate_key_dict(
+            dictionary=dataset_info, key="project_id"
+        )
+        group = file_utils.helper_validate_key_dict(
+            dictionary=dataset_info, key="group", default_return="MSMA"
+        )
+
         # Creating data description
         data_description = RawDataDescription(
             modality=[Modality.SPIM],
-            experiment_type=ExperimentType.SMARTSPIM,
             subject_id=parsed_data["mouse_id"],
             creation_date=date(
                 mouse_date.year, mouse_date.month, mouse_date.day
@@ -311,12 +510,12 @@ class SmartSPIMWriter:
             creation_time=time(
                 mouse_date.hour, mouse_date.minute, mouse_date.second
             ),
-            # Parses the attribute name to an institution...
-            institution=Institution(dataset_info["institution"]),
-            group=Group.MSMA,
-            project_name=dataset_info["project"],
-            project_id=dataset_info["project_id"],
-            funding_source=[Funding(funder=dataset_info["institution"])],
+            institution=institution,
+            group=group,
+            project_name=project_name,
+            project_id=project_id,
+            funding_source=[Funding(funder=funding_source)],
+            experiment_type=ExperimentType.SMARTSPIM,
         )
 
         data_description_path = str(
@@ -386,7 +585,7 @@ class SmartSPIMWriter:
         dataset_path: PathLike
             Path where the channels of the dataset
             are stored
-        
+
         Returns
         ------------
         dict
@@ -409,7 +608,7 @@ class SmartSPIMWriter:
 
         return excitation_emission_channels
 
-    def __create_adquisition(
+    def __create_acquisition(
         self,
         parsed_data: dict,
         dataset_info: dict,
@@ -439,27 +638,101 @@ class SmartSPIMWriter:
             original_dataset_path
         )
 
-        with open(mdata_file, "rb") as file:
-            lc_mdata = file.readlines()
+        with open(mdata_file, "rb") as f:
+            lc_mdata_result = chardet.detect(f.read())
+
+        with open(mdata_file, "r", encoding=lc_mdata_result["encoding"]) as f:
+            lc_mdata = f.readlines()
+
+        # Get information where starts each metadata block
+        # in the metadata file
+        line_indices = get_line_indices_metadata_file(lc_mdata)
+
+        # Parse first section
+        session_config = get_session_config(lines=lc_mdata)
+
+        # Getting wavelengths
+        wavelength_config = get_wavelength_config(
+            lines=lc_mdata,
+            start_index=line_indices["wavelength_start"] + 1,
+            end_index=line_indices["tile_acquisition_start"],
+        )
+
+        # Getting tile info
+        tile_config = get_tile_info(
+            lines=lc_mdata,
+            start_index=line_indices["tile_acquisition_start"] + 1,
+        )
+
+        metadata_dict = {
+            "session_config": session_config,
+            "wavelength_config": wavelength_config,
+            "tile_config": tile_config,
+        }
 
         session_end_time = get_session_end(asi_file)
 
+        # Validating data in config
+        instrument_id = file_utils.helper_validate_key_dict(
+            dictionary=dataset_info, key="instrument_id"
+        )
+        experimenter_full_name = file_utils.helper_validate_key_dict(
+            dictionary=dataset_info, key="experimenter"
+        )
+        local_storage_directory = file_utils.helper_validate_key_dict(
+            dictionary=dataset_info, key="local_storage"
+        )
+        chamber_immersion_medium = file_utils.helper_validate_key_dict(
+            dictionary=dataset_info["chamber_immersion"], key="medium"
+        )
+        chamber_immersion_ri = file_utils.helper_validate_key_dict(
+            dictionary=dataset_info["chamber_immersion"],
+            key="refractive_index",
+        )
+        sample_immersion_medium = file_utils.helper_validate_key_dict(
+            dictionary=dataset_info["sample_immersion"], key="medium"
+        )
+        sample_immersion_ri = file_utils.helper_validate_key_dict(
+            dictionary=dataset_info["sample_immersion"], key="refractive_index"
+        )
+
+        # Giving the specific error of what is missing
+        if instrument_id is None:
+            raise ValueError("Instrument id not provided in manifest")
+
+        if experimenter_full_name is None:
+            raise ValueError("Experimenter full name not provided in manifest")
+
+        if chamber_immersion_medium is None:
+            raise ValueError(
+                "Chamber immersion medium not provided in manifest"
+            )
+
+        if chamber_immersion_ri is None:
+            raise ValueError("Chamber immersion ri not provided in manifest")
+
         acquisition_model = acquisition.Acquisition(
             specimen_id="",
-            instrument_id=dataset_info["instrument_id"],
-            experimenter_full_name=dataset_info["experimenter"],
+            instrument_id=instrument_id,
+            experimenter_full_name=experimenter_full_name,
             subject_id=parsed_data["mouse_id"],
             session_start_time=parsed_data["mouse_date"],
             session_end_time=session_end_time,
-            local_storage_directory=dataset_info["local_storage_directory"],
+            local_storage_directory=local_storage_directory,
             external_storage_directory="",
             chamber_immersion=acquisition.Immersion(
-                medium=dataset_info["immersion"]["medium"],
-                refractive_index=dataset_info["immersion"]["refractive_index"],
+                medium=chamber_immersion_medium,
+                refractive_index=chamber_immersion_ri,
+            ),
+            sample_immersion=acquisition.Immersion(
+                medium=sample_immersion_medium,
+                refractive_index=sample_immersion_ri,
             ),
             axes=[
                 acquisition.Axis(
-                    name="X", dimension=2, direction="Left_to_right",
+                    name="X",
+                    dimension=2,
+                    direction="Left_to_right",
                 ),
                 acquisition.Axis(
                     name="Y", dimension=1, direction="Posterior_to_anterior"
@@ -468,7 +741,9 @@ class SmartSPIMWriter:
                     name="Z", dimension=0, direction="Superior_to_inferior"
                 ),
             ],
-            tiles=make_acq_tiles(lc_mdata, filter_mapping),
+            tiles=make_acq_tiles(
+                metadata_dict=metadata_dict, filter_mapping=filter_mapping
+            ),
         )
 
         acquisition_path = str(output_path.joinpath("acquisition.json"))
@@ -514,17 +789,20 @@ class SmartSPIMWriter:
         # Creates the subject metadata json
         self.__create_subject(parsed_data["mouse_id"], output_path)
 
-        # Creates the adquisition json
-        if "adquisition" in dataset_info:
-            self.__create_adquisition(
-                parsed_data,
-                dataset_info["adquisition"],
-                original_dataset_path,
-                output_path,
-            )
+        # Creates the acquisition json
+        if "acquisition" in dataset_info:
+            try:
+                self.__create_acquisition(
+                    parsed_data,
+                    dataset_info["acquisition"],
+                    original_dataset_path,
+                    output_path,
+                )
+            except ValueError:
+                logger.error("Error creating acquisition schema")
         else:
             logger.error(
-                f"adquisition.json was not created for {parsed_data['mouse_id']}. Add it to the YAML configuration."
+                f"acquisition.json was not created for {parsed_data['mouse_id']}. Add it to the YAML configuration."
             )
 
     def prepare_datasets(
@@ -558,7 +836,7 @@ class SmartSPIMWriter:
             dataset_path = dataset_info["path"]
 
             if os.path.isdir(dataset_path):
-                logger.info(f"Processing: {dataset_path}\n")
+                logger.info(f"\nOrganizing: {dataset_path}")
                 (
                     new_dataset_path,
                     parsed_data,
@@ -606,11 +884,6 @@ class SmartSPIMWriter:
                         mode=mode,
                     )
 
-                    file_utils.write_list_to_txt(
-                        new_dataset_path.joinpath("DATASET_STATUS.txt"),
-                        ["PENDING"],
-                    )
-
                     new_dataset_paths.append(new_dataset_path)
 
                 else:
